@@ -662,7 +662,23 @@ def generate_random_correl_matrix(size: int, corr_max: float):
     return res
 
 
+def find_orthogonal_vector(v):
+    if type(v) is list:
+        v = pd.DataFrame(v)
+    n, _ = v.shape
+    assert (n > 1)
+    assert (not all([v.iloc[i, 0] == 0 for i in range(n)]))
+    istar = np.argmin([1 if v.iloc[i, 0] != 0 else 0 for i in range(n)])
+    w = pd.DataFrame(index=range(n), columns=["C"])
+    w.fillna(value=0, inplace=True)
+    istarplus1 = (istar + 1) % n
+    w.iloc[istar, 0] = -v.iloc[istarplus1, 0]
+    w.iloc[istarplus1, 0] = v.iloc[istar, 0]
+    return w
+
+
 def generate_vectors_bouquet(vpivot, bouquet_size: int, min_corr: float) -> pd.DataFrame:
+
     pass
 
 
